@@ -1,4 +1,18 @@
 //! This crate provides the macro [`mongo_db`] to model a mongoDB database.
+//!
+//! # Features
+//!
+//! Feature flags are documented here.
+//!
+//! ## `default`
+//!
+//! This feature enables the following feature(s):
+//!
+//! - `mongodb-gridfs`
+//!
+//! ## `mongodb-gridfs`
+//!
+//! Enabling this feature creates automatic implementations of the then-available trait `GridFSDb`.
 
 /// To make [`mongo_db`] work reliably a couple of re-exports are needed, these are not relevant for using the macro.
 #[doc(hidden)]
@@ -10,6 +24,9 @@ pub mod traits;
 #[doc(hidden)]
 pub use crate::mongodb_ext_derive::case;
 
+#[cfg(feature = "mongodb-gridfs")]
+pub use crate::traits::GridFSDb;
+
 pub use crate::traits::{MongoClient, MongoCollection};
 
 /// Defines the default type inside an [`Option`] for the `_id` field.
@@ -296,6 +313,13 @@ macro_rules! expand_main_client {
                 async fn ping(&self) -> $crate::mongodb::error::Result<$crate::mongodb::bson::document::Document> {
                     self.database.run_command($crate::mongodb::bson::doc!{"ping": 1}, std::option::Option::None).await
                 }
+
+                fn database(&self) -> &$crate::mongodb::Database {
+                    &self.database
+                }
+                fn client(&self) -> &$crate::mongodb::Client {
+                    &self.client
+                }
             }
             $(
                 impl $db_name {
